@@ -6,6 +6,22 @@ from ..models import *
 
 register = template.Library()
 
+@register.simple_tag
+def autodidact_version():
+    try:
+        import autodidact
+        return autodidact.__version__
+    except ImportError:
+        return 'unknown'
+
+@register.simple_tag
+def bps_version():
+    try:
+        import bps
+        return bps.__version__
+    except ImportError:
+        return 'unknown'
+
 @register.inclusion_tag('autodidact/include/editor.html', takes_context=True)
 def autodidact_editor(context):
     context['edit_type'] = context['request'].resolver_match.view_name
